==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/at/articles.php <==
<?php
regGS("to section", "in Rubrik");
regGS("You must select at least one article to perform an action.", "Für diese Aktion muss mindestens ein Artikel ausgewählt sein.");
regGS("You must choose a language", "Eine Sprache muss ausgewählt werden");
regGS("You may only translate one article at a time.", "Es kann immer nur ein Artikel übersetzt werden.");
regGS("View article", "Artikel ansehen");
regGS("Unable to create the section for translation $1.", "Fehler beim Erstellen der Rubrik für Übersetzung $1");
regGS("Unable to create the issue for translation $1.", "Fehler beim Erstellen der Ausgabe für Übersetzung $1");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Die folgenden Artikel sind neu und können deshalb nicht für die automatisierte Veröffentlichung genutzt werden");
regGS("Status: Submitted", "Status: angelegt");
regGS("Status: Submit", "Status: anlegen");
regGS("Status: Set New", "Status: auf neu setzen");
regGS("Status: Published", "Status: veröffentlicht");
regGS("Status: Publish", "Status: veröffentlichen");
regGS("Status: New", "Status: neu");
regGS("Select None", "Keine auswählen");
regGS("Select All", "Alle auswählen");
regGS("Section URL Name", "URL Name der Rubrik");
regGS("Section Name", "Rubrikenname");
regGS("Reorder", "Nachbestellen");
regGS("Publish date", "Veröffentlichungsdatum");
regGS("Publish Schedule", "Automatisierte Veröffentlichung");
regGS("On Section Page", "Auf der Rubrikenseite");
regGS("On Front Page", "Auf der Startseite");
regGS("No action specified", "Es wurde keine Aktion angegeben");
regGS("New section name", "Neuer Rubrikenname");
regGS("New section URL name", "Neuer URL Name für die Rubrik");
regGS("New issue name", "Neuer Ausgabenname");
regGS("New issue URL name", "Neuer URL Name für die Ausgabe");
regGS("New article name", "Neuer Artikelname");
regGS("Issue URL Name", "URL Name der Ausgabe");
regGS("Issue Name", "Ausgabenname");
regGS("Files", "Dateien");
regGS("Duplicate?", "Duplizieren?");
regGS("Duplicate to another section", "In andere Rubrik duplizieren");
regGS("Duplicate articles", "Artikel duplizieren");
regGS("Creation date", "Erstellungsdatum");
regGS("Created by", "Erstellt von");
regGS("Author", "AutorIn");
regGS("Article name ($1)", "Artikelname ($1)");
regGS("Article List", "Artikelliste");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Soll das Thema '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Soll die Datei '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Soll das automatisierte Ereignis vom $1 entfernt werden?");
regGS("Are you sure you want to delete this article?", "Soll der Artikel gelöscht werden?");
regGS("Are you sure you want to delete the selected articles?", "Sollen sie ausgewählten Artikel gelöscht werden?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Eine Ausgabe muss für die ausgewählte Sprache angelegt werden. Bitte Namen für Ausgabe und URL angeben.");
regGS("All", "Alle");
regGS("Add Event", "Ereignis hinzufügen");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Eine Rubrik muss für die ausgewählte Sprache angelegt werden. Bitte Namen für Ausgabe und URL angeben.");
regGS("Article Type", "Artikeltyp");
regGS("$1 articles found", "$1 Artikel wurden gefunden");
regGS("Show article on front page", "Artikel auf der Startseite anzeigen");
regGS("Show article on section page", "Artikel in der Rubrik anzeigen");
regGS("Translate article", "Artikel übersetzen.");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Keine Berechtigung, den Artikel zu ändern.  Bearbeiten nur von eigenen Artikeln möglich. Bereits eingepflegte Artikel können nur von autorisierten Usern verändert werden.");
regGS("Edit article", "Artikeldetails bearbeiten");
regGS("Allow users without subscriptions to view the article", "BenutzerInnen ohne Abonoment Ansicht des Artikels erlauben");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Der Artikel wurde von $1 ($2) gesperrt, vor $3 Stunden und $4 Minuten.");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Der Artikel wurde von $1 ($2) gesperrt, vor $3 Minuten.");
regGS("Are you sure you want to unlock it?", "Wirklich freigeben?");
regGS("Article is locked", "Der Artikel ist gesperrt");
regGS("Duplicate article", "Artikel duplizieren");
regGS("The destination section is the same as the source section.", "Die Zielrubrik ist identisch mit der Ausgangsrubrik.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Der Artikel ist neu und kann deshalb nicht für die automatisierte Veröffentlichung benutzt werden.");
regGS("No article types were defined. You must create an article type first.", "Zuerst müssen Artikeltypen angelegt werden.");
regGS("Edit article types", "Artikeltypen editieren");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Fehler beim Speichern des Artikels. Er wurde von $1 vor $2 Stunden und $3 Minuten gesperrt.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Keine Zugriffsrechte auf die Änderung des Artikelstatus. Eingepflegte Artikel können nur mit den dazugehörigen Rechten geändert werden.");
regGS("You do not have the right to delete articles.", "Fehlende Zugriffsrechte für das Löschen von Artikeln.");
regGS("You must select an article type.", "Ein Artikeltyp muss ausgewählt werden.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("Are you sure you want to remove the topic \\'$1\\' from the article?", "Soll das Thema '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the file \\'$1\\' from the article?", "Soll die Datei '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Soll das Bild '$1' vom Artikel entkoppelt werden?");
?>

==> campsite-2.6.7_5.tbz: campsite/www-common/html/priv/lang/at/articles.php <==
<?php 
regGS("Select location:", "");
regGS("You cannot have two articles in the same section with the same name.  The article name you specified is already in use by the article '$1'.", "");
regGS("Visible to non-subscribers", "");
regGS("The article could not be published.", "");
regGS("Scheduled action deleted.", "");
regGS("Scheduled action added.", "");
regGS("Article(s) unlocked.", "");
regGS("Article(s) duplicated.", "");
regGS("Article(s) deleted.", "");
regGS("Article status set to '$1'", "");
regGS("Article unlocked.", "");
regGS("Article translation created.", "");
regGS("Article order changed.", "");
regGS("Article moved.", "");
regGS("Article deleted.", "");
regGS("Article created.", "");
regGS("$1 toggled.", "");
regGS("Total:", "");
regGS("Toggle '$1'", "");
regGS("Show Comments", "");
regGS("Saved:", "");
regGS("Locked", "");
regGS("Link to public page", "");
regGS("Invalid type: $1", "");
regGS("Hide Comments", "");
regGS("Enabled", "");
regGS("Disabled", "");
regGS("Comments:", "");
regGS("Comments", "");
regGS("The article has already been translated into $1.", "");
regGS("You must set the publication, issue, and section for this article before you can schedule it for publishing.  Go to the \"$1\" menu and select \"$2\" to do this.", "");
regGS("You do not have the right to translate articles.", "");
regGS("You do not have the right to publish articles.", "");
regGS("You do not have the right to move articles.", "");
regGS("You cannot $1 the articles marked in red because the destination issue has not been translated into the appropriate language.", "");
regGS("Publish?", "");
regGS("Publish articles", "");
regGS("Publish article", "");
regGS("Move?", "");
regGS("Move articles", "");
regGS("Move article", "");
regGS("to section", "in Rubrik");
regGS("You must select at least one article to perform an action.", "Für diese Aktion muss mindestens ein Artikel ausgewählt sein.");
regGS("You must choose a language", "Eine Sprache muss ausgewählt werden");
regGS("You may only translate one article at a time.", "Es kann immer nur ein Artikel übersetzt werden.");
regGS("View article", "Artikel ansehen");
regGS("Unable to create the section for translation $1.", "Fehler beim Erstellen der Rubrik für Übersetzung $1");
regGS("Unable to create the issue for translation $1.", "Fehler beim Erstellen der Ausgabe für Übersetzung $1");
regGS("The following articles are new; it is not possible to schedule them for automatic publishing", "Die folgenden Artikel sind neu und können deshalb nicht für die automatisierte Veröffentlichung genutzt werden");
regGS("Status: Submitted", "Status: angelegt");
regGS("Status: Submit", "Status: anlegen");
regGS("Status: Set New", "Status: auf neu setzen");
regGS("Status: Published", "Status: veröffentlicht");
regGS("Status: Publish", "Status: veröffentlichen");
regGS("Status: New", "Status: neu");
regGS("Section URL Name", "URL Name der Rubrik");
regGS("Section Name", "Rubrikenname");
regGS("Reorder", "Nachbestellen");
regGS("Publish date", "Veröffentlichungsdatum");
regGS("Publish Schedule", "Automatisierte Veröffentlichung");
regGS("No action specified", "Es wurde keine Aktion angegeben");
regGS("New section name", "Neuer Rubrikenname");
regGS("New section URL name", "Neuer URL Name für die Rubrik");
regGS("New issue name", "Neuer Ausgabenname");
regGS("New issue URL name", "Neuer URL Name für die Ausgabe");
regGS("New article name", "Neuer Artikelname");
regGS("Issue URL Name", "URL Name der Ausgabe");
regGS("Issue Name", "Ausgabenname");
regGS("Files", "Dateien");
regGS("Duplicate?", "Duplizieren?");
regGS("Duplicate to another section", "In andere Rubrik duplizieren");
regGS("Duplicate articles", "Artikel duplizieren");
regGS("Author", "AutorIn");
regGS("Article name ($1)", "Artikelname ($1)");
regGS("Article List", "Artikelliste");
regGS("Are you sure you want to remove the topic \'$1\' from the article?", "Soll das Thema '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the file \'$1\' from the article?", "Soll die Datei '$1' von diesem Artikel entkoppelt werden?");
regGS("Are you sure you want to remove the event scheduled on $1?", "Soll das automatisierte Ereignis vom $1 entfernt werden?");
regGS("Are you sure you want to delete this article?", "Soll der Artikel gelöscht werden?");
regGS("Are you sure you want to delete the selected articles?", "Sollen sie ausgewählten Artikel gelöscht werden?");
regGS("An issue must be created for the selected language.  Please enter the issue name and URL name.", "Eine Ausgabe muss für die ausgewählte Sprache angelegt werden. Bitte Namen für Ausgabe und URL angeben.");
regGS("A section must be created for the selected language.  Please enter the section name and URL name.", "Eine Rubrik muss für die ausgewählte Sprache angelegt werden. Bitte Namen für Ausgabe und URL angeben.");
regGS("Article Type", "Artikeltyp");
regGS("$1 articles found", "$1 Artikel wurden gefunden");
regGS("Show article on front page", "Artikel auf der Startseite anzeigen");
regGS("Show article on section page", "Artikel in der Rubrik anzeigen");
regGS("Translate article", "Artikel übersetzen.");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Keine Berechtigung, den Artikel zu ändern.  Bearbeiten nur von eigenen Artikeln möglich. Bereits eingepflegte Artikel können nur von autorisierten Usern verändert werden.");
regGS("Edit article", "Artikeldetails bearbeiten");
regGS("The article has been locked by $1 ($2) $3 hour(s) and $4 minute(s) ago.", "Der Artikel wurde von $1 ($2) gesperrt, vor $3 Stunden und $4 Minuten.");
regGS("The article has been locked by $1 ($2) $3 minute(s) ago.", "Der Artikel wurde von $1 ($2) gesperrt, vor $3 Minuten.");
regGS("Article is locked", "Der Artikel ist gesperrt");
regGS("Duplicate article", "Artikel duplizieren");
regGS("The destination section is the same as the source section.", "Die Zielrubrik ist identisch mit der Ausgangsrubrik.");
regGS("The article is new; it is not possible to schedule it for automatic publishing.", "Der Artikel ist neu und kann deshalb nicht für die automatisierte Veröffentlichung benutzt werden.");
regGS("No article types were defined. You must create an article type first.", "Zuerst müssen Artikeltypen angelegt werden.");
regGS("Edit article types", "Artikeltypen editieren");
regGS("Could not save the article. It has been locked by $1 $2 hours and $3 minutes ago.", "Fehler beim Speichern des Artikels. Er wurde von $1 vor $2 Stunden und $3 Minuten gesperrt.");
regGS("You do not have the right to change this article status. Once submitted an article can only be changed by authorized users.", "Keine Zugriffsrechte auf die Änderung des Artikelstatus. Eingepflegte Artikel können nur mit den dazugehörigen Rechten geändert werden.");
regGS("You do not have the right to delete articles.", "Fehlende Zugriffsrechte für das Löschen von Artikeln.");
regGS("You must select an article type.", "Ein Artikeltyp muss ausgewählt werden.");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Soll das Bild '$1' vom Artikel entkoppelt werden?");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("There was an error reading request parameters.", "Fehler beim Lesen der Anfrage");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "Dieser Artikel kann nicht in der Vorschau angezeigt werden. Bitte prüfen, ob eine Template ausgewählt wurde.");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "Diese Ausgabe kann nicht in der Vorschau angezeigt werden. Bitte prüfen, ob eine Template ausgewählt wurde.");
regGS("Insert Internal Link", "Internen Link hinzugügen");
regGS("No such article.", "Artikel nicht vorhanden");
regGS("No such section.", "Rubrik nicht vorhanden");
?>
